@@ -10,7 +10,7 @@ from typing import Any, Dict, List, Type
 
 from swh.core.config import load_named_config
 from swh.core.config import read as read_config
-from swh.model.identifiers import CoreSWHID, ObjectType
+from swh.model.swhids import CoreSWHID, ObjectType
 from swh.storage import get_storage
 from swh.vault import get_vault
 from swh.vault.cookers.base import DEFAULT_CONFIG, DEFAULT_CONFIG_PATH, BaseVaultCooker
